# coding: utf-8
# file generated by setuptools_scm
# don't change, don't track in version control
from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from typing import Tuple, Union

    VERSION_TUPLE = Tuple[
        Union[int, str], Union[int, str], Union[int, str], Union[int, str], Union[int, str]
    ]
    COMMIT_ID = str
else:
    VERSION_TUPLE = object
    COMMIT_ID = object


version: str
__version__: str
__version_tuple__: VERSION_TUPLE
version_tuple: VERSION_TUPLE
commit_id: COMMIT_ID
__commit_id__: COMMIT_ID

__version__ = version = '1.0.0'
__version_tuple__ = version_tuple = (1, 0, 0, 'final', '0')

__commit_id__ = commit_id = 'g62277cb82'